skipUnregisterIfNotRegistered property

bool skipUnregisterIfNotRegistered
getter/setter pair

By default unregister throws if there is no matching registration, because that usually means that you call unregister/dispose once too often. If you don't want GetIt to check this, set this to true and a missing registration will be silently ignored by unregister.

Implementation

bool skipUnregisterIfNotRegistered = false;