NfeModule class

Inheritance

Constructors

NfeModule({required GetIt instance})

Properties

createNfeToRun ↔ CreateNfeToRun
getter/setter pair
getNfeStatusByPeople ↔ GetNfeStatusByPeople
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
instance ↔ GetIt
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

init() → Future
override
injectModule() → Future
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited