LoginRepositoryImpl class

Inheritance

Constructors

LoginRepositoryImpl(HttpService httpService, StorageService storageService)

Properties

hashCode int
The hash code for this object.
no setterinherited
httpService HttpService
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storageService StorageService
final

Methods

getLoggedUserId() Future<String?>
override
getLoggedUserToken() Future<String?>
override
makeLogin({required String appId, required String username, required String password, String? playerId}) Future<LoginModel?>
override
makeLoginOnlyKey({required String key, required String appId, String? playerId}) Future<LoginModel?>
override
makeLogout() Future<bool>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rememberPassword({required String email, required String appId}) Future<String?>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited